==> qtjambi-webenginecore-debuginfo-macos-6.5.3.jar: sources/QtJambiWebEngineCore/QtWebEngineCore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginecertificateerror.h>
#include <QtCore/QVariant>
#include <qwebenginecontextmenurequest.h>
#include <QtWebEngineCore/qtwebenginecoreglobal.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QtWebEngineCore::qWebEngineChromiumSecurityPatchVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineChromiumSecurityPatchVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineChromiumSecurityPatchVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineChromiumSecurityPatchVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtWebEngineCore::qWebEngineChromiumVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineChromiumVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineChromiumVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineChromiumVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtWebEngineCore::qWebEngineVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtWebEngineCore(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QtWebEngineCore", "io/qt/webengine/core/QtWebEngineCore", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfo<QtWebEngineCore::ReferrerPolicy>("QtWebEngineCore::ReferrerPolicy", "io/qt/webengine/core/QtWebEngineCore$ReferrerPolicy");
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-macos-6.6.0.jar: sources/QtJambiWebEngineCore/QtWebEngineCore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginecertificateerror.h>
#include <QtCore/QVariant>
#include <qwebenginecontextmenurequest.h>
#include <QtWebEngineCore/qtwebenginecoreglobal.h>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QtWebEngineCore::qWebEngineChromiumSecurityPatchVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineChromiumSecurityPatchVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineChromiumSecurityPatchVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineChromiumSecurityPatchVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtWebEngineCore::qWebEngineChromiumVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineChromiumVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineChromiumVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineChromiumVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtWebEngineCore::qWebEngineGetDomainAndRegistry(QUrl)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineGetDomainAndRegistry_1native_1cref_1QUrl__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID url0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineGetDomainAndRegistry(QUrl)")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        QString __qt_return_value = qWebEngineGetDomainAndRegistry(__qt_url0);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QtWebEngineCore::qWebEngineVersion()
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QtWebEngineCore_qWebEngineVersion__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtWebEngineCore::qWebEngineVersion()")
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const char* __qt_return_value = qWebEngineVersion();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtWebEngineCore(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QtWebEngineCore", "io/qt/webengine/core/QtWebEngineCore", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfo<QtWebEngineCore::ReferrerPolicy>("QtWebEngineCore::ReferrerPolicy", "io/qt/webengine/core/QtWebEngineCore$ReferrerPolicy");
// END: enums and flags
}
